@@ -738,6 +738,39 @@ class SqueakAdminServerHandler(object):
             sent_payments=sent_payment_msgs,
         )
 
+    def handle_get_sent_payments_for_squeak(self, request):
+        squeak_hash_str = request.squeak_hash
+        squeak_hash = bytes.fromhex(squeak_hash_str)
+        limit = request.limit
+        last_sent_payment = message_to_sent_payment(request.last_sent_payment) if request.HasField(
+            "last_sent_payment") else None
+        logger.info("""Handle get sent payments with
+        squeak_hash: {}
+        limit: {}
+        last_sent_payment: {}
+        """.format(
+            squeak_hash_str,
+            limit,
+            last_sent_payment,
+        ))
+        sent_payments = self.squeak_controller.get_sent_payments_for_squeak(
+            squeak_hash,
+            limit,
+            last_sent_payment,
+        )
+        logger.info(
+            "Got number of sent payments: {}".format(
+                len(sent_payments)
+            )
+        )
+        sent_payment_msgs = [
+            sent_payment_to_message(sent_payment)
+            for sent_payment in sent_payments
+        ]
+        return squeak_admin_pb2.GetSentPaymentsReply(
+            sent_payments=sent_payment_msgs,
+        )
+
     def handle_get_sent_payment(self, request):
         sent_payment_id = request.sent_payment_id
         logger.info(
@@ -786,6 +819,39 @@ class SqueakAdminServerHandler(object):
             received_payments=received_payment_msgs,
         )
 
+    def handle_get_received_payments_for_squeak(self, request):
+        squeak_hash_str = request.squeak_hash
+        squeak_hash = bytes.fromhex(squeak_hash_str)
+        limit = request.limit
+        last_received_payment = message_to_received_payment(request.last_received_payment) if request.HasField(
+            "last_received_payment") else None
+        logger.info("""Handle get received payments with
+        squeak_hash: {}
+        limit: {}
+        last_received_payment: {}
+        """.format(
+            squeak_hash,
+            limit,
+            last_received_payment,
+        ))
+        received_payments = self.squeak_controller.get_received_payments_for_squeak(
+            squeak_hash,
+            limit,
+            last_received_payment,
+        )
+        logger.info(
+            "Got number of received payments: {}".format(
+                len(received_payments)
+            )
+        )
+        received_payment_msgs = [
+            received_payment_to_message(received_payment)
+            for received_payment in received_payments
+        ]
+        return squeak_admin_pb2.GetReceivedPaymentsReply(
+            received_payments=received_payment_msgs,
+        )
+
     def handle_subscribe_received_payments(self, request, stopped):
         payment_index = request.payment_index
         logger.info(
@@ -820,6 +886,24 @@ class SqueakAdminServerHandler(object):
             payment_summary=payment_summary_msg,
         )
 
+    def handle_get_payment_summary_for_squeak(self, request):
+        squeak_hash_str = request.squeak_hash
+        squeak_hash = bytes.fromhex(squeak_hash_str)
+        logger.info("Handle get payment summary for squeak hash: {}".format(
+            squeak_hash_str,
+        ))
+        received_payment_summary = self.squeak_controller.get_received_payment_summary_for_squeak(
+            squeak_hash)
+        sent_payment_summary = self.squeak_controller.get_sent_payment_summary_for_squeak(
+            squeak_hash)
+        payment_summary_msg = payment_summary_to_message(
+            received_payment_summary,
+            sent_payment_summary,
+        )
+        return squeak_admin_pb2.GetPaymentSummaryForSqueakReply(
+            payment_summary=payment_summary_msg,
+        )
+
     def handle_reprocess_received_payments(self, request):
         logger.info("Handle reprocess received payments")
         self.squeak_controller.reprocess_received_payments()
