@@ -215,6 +215,9 @@ class SqueakAdminServerServicer(squeak_admin_pb2_grpc.SqueakAdminServicer):
     def GetSentPayments(self, request, context):
         return self.handler.handle_get_sent_payments(request)
 
+    def GetSentPaymentsForSqueak(self, request, context):
+        return self.handler.handle_get_sent_payments_for_squeak(request)
+
     def GetSentPayment(self, request, context):
         return self.handler.handle_get_sent_payment(request)
 
@@ -224,6 +227,9 @@ class SqueakAdminServerServicer(squeak_admin_pb2_grpc.SqueakAdminServicer):
     def GetReceivedPayments(self, request, context):
         return self.handler.handle_get_received_payments(request)
 
+    def GetReceivedPaymentsForSqueak(self, request, context):
+        return self.handler.handle_get_received_payments_for_squeak(request)
+
     def SubscribeReceivedPayments(self, request, context):
         stopped = threading.Event()
 
@@ -242,6 +248,9 @@ class SqueakAdminServerServicer(squeak_admin_pb2_grpc.SqueakAdminServicer):
     def GetPaymentSummary(self, request, context):
         return self.handler.handle_get_payment_summary(request)
 
+    def GetPaymentSummaryForSqueak(self, request, context):
+        return self.handler.handle_get_payment_summary_(request)
+
     def ReprocessReceivedPayments(self, request, context):
         return self.handler.handle_reprocess_received_payments(request)
 
