@@ -121,12 +121,6 @@ def create_app(handler, username, password):
         logger.info("Getting user.")
         return current_user.username
 
-    @app.route("/hello")
-    @login_required
-    def hello_world():
-        logger.info("Getting hello route.")
-        return "Hello, World!"
-
     @app.route("/lndgetinfo", methods=["POST"])
     @login_required
     @protobuf_serialized(lnd_pb2.GetInfoRequest())
@@ -427,6 +421,12 @@ def create_app(handler, username, password):
     def getsentpayments(msg):
         return handler.handle_get_sent_payments(msg)
 
+    @app.route("/getsentpaymentsforsqueak", methods=["POST"])
+    @login_required
+    @protobuf_serialized(squeak_admin_pb2.GetSentPaymentsForSqueakRequest())
+    def getsentpaymentsforsqueak(msg):
+        return handler.handle_get_sent_payments_for_squeak(msg)
+
     @app.route("/getsentoffers", methods=["POST"])
     @login_required
     @protobuf_serialized(squeak_admin_pb2.GetSentOffersRequest())
@@ -439,6 +439,12 @@ def create_app(handler, username, password):
     def getreceivedpayments(msg):
         return handler.handle_get_received_payments(msg)
 
+    @app.route("/getreceivedpaymentsforsqueak", methods=["POST"])
+    @login_required
+    @protobuf_serialized(squeak_admin_pb2.GetReceivedPaymentsForSqueakRequest())
+    def getreceivedpaymentsforsqueak(msg):
+        return handler.handle_get_received_payments_for_squeak(msg)
+
     @app.route("/getnetwork", methods=["POST"])
     @login_required
     @protobuf_serialized(squeak_admin_pb2.GetNetworkRequest())
@@ -457,6 +463,12 @@ def create_app(handler, username, password):
     def getpaymentsummary(msg):
         return handler.handle_get_payment_summary(msg)
 
+    @app.route("/getpaymentsummaryforsqueak", methods=["POST"])
+    @login_required
+    @protobuf_serialized(squeak_admin_pb2.GetPaymentSummaryForSqueakRequest())
+    def getpaymentsummaryforsqueak(msg):
+        return handler.handle_get_payment_summary_for_squeak(msg)
+
     @app.route("/reprocessreceivedpayments", methods=["POST"])
     @login_required
     @protobuf_serialized(squeak_admin_pb2.ReprocessReceivedPaymentsRequest())
