@@ -38,7 +38,6 @@ from squeaknode.core.received_payment import ReceivedPayment
 from squeaknode.core.received_payment_summary import ReceivedPaymentSummary
 from squeaknode.core.sent_payment import SentPayment
 from squeaknode.core.sent_payment_summary import SentPaymentSummary
-from squeaknode.core.squeak_core import SqueakCore
 from squeaknode.core.squeak_entry import SqueakEntry
 from squeaknode.core.squeak_peer import SqueakPeer
 from squeaknode.core.squeak_profile import SqueakProfile
@@ -59,22 +58,18 @@ class SqueakController:
     def __init__(
         self,
         squeak_store: SqueakStore,
-        squeak_core: SqueakCore,
         payment_processor,
         tweet_forwarder,
         network_controller,
         node_settings,
         config,
-        default_port,
     ):
         self.squeak_store = squeak_store
-        self.squeak_core = squeak_core
         self.payment_processor = payment_processor
         self.tweet_forwarder = tweet_forwarder
         self.network_controller = network_controller
         self.node_settings = node_settings
         self.config = config
-        self.default_port = default_port
 
     def make_squeak(
             self,
@@ -83,54 +78,15 @@ class SqueakController:
             replyto_hash: Optional[bytes],
             recipient_profile_id: Optional[int],
     ) -> Optional[bytes]:
-        squeak_profile = self.squeak_store.get_squeak_profile(profile_id)
-        if squeak_profile is None:
-            raise Exception("Profile with id {} not found.".format(
-                profile_id,
-            ))
-        if recipient_profile_id:
-            recipient_profile = self.squeak_store.get_squeak_profile(
-                recipient_profile_id)
-            if recipient_profile is None:
-                raise Exception("Recipient profile with id {} not found.".format(
-                    recipient_profile_id,
-                ))
-        squeak, secret_key = self.squeak_core.make_squeak(
-            squeak_profile,
+        return self.squeak_store.make_squeak(
+            profile_id,
             content_str,
             replyto_hash,
-            recipient_profile=recipient_profile if recipient_profile_id else None,
+            recipient_profile_id,
         )
-        inserted_squeak_hash = self.squeak_store.save_squeak(squeak)
-        if inserted_squeak_hash is None:
-            raise Exception("Failed to save squeak.")
-        self.squeak_store.save_secret_key(inserted_squeak_hash, secret_key)
-        if squeak.is_private_message:
-            self.squeak_store.unlock_squeak(
-                inserted_squeak_hash,
-                author_profile_id=profile_id,
-            )
-        return inserted_squeak_hash
 
     def pay_offer(self, received_offer_id: int) -> int:
-        received_offer = self.squeak_store.get_received_offer(
-            received_offer_id,
-        )
-        if received_offer is None:
-            raise Exception("Received offer with id {} not found.".format(
-                received_offer_id,
-            ))
-        logger.info("Paying received offer: {}".format(received_offer))
-        sent_payment = self.squeak_core.pay_offer(received_offer)
-        sent_payment_id = self.squeak_store.save_sent_payment(sent_payment)
-        self.squeak_store.mark_received_offer_paid(
-            sent_payment.payment_hash,
-        )
-        self.squeak_store.save_secret_key(
-            received_offer.squeak_hash,
-            sent_payment.secret_key,
-        )
-        return sent_payment_id
+        return self.squeak_store.pay_offer(received_offer_id)
 
     def get_packaged_offer(
             self,
@@ -143,7 +99,6 @@ class SqueakController:
                 host=self.config.lnd.external_host,
                 port=self.config.lnd.port,
             )
-        logger.info(lnd_external_address)
         price_msat = self.get_sell_price_msat()
         if price_msat == 0:
             return None
@@ -263,6 +218,18 @@ class SqueakController:
             last_sent_payment,
         )
 
+    def get_sent_payments_for_squeak(
+            self,
+            squeak_hash: bytes,
+            limit: int,
+            last_sent_payment: Optional[SentPayment],
+    ) -> List[SentPayment]:
+        return self.squeak_store.get_sent_payments_for_squeak(
+            squeak_hash,
+            limit,
+            last_sent_payment,
+        )
+
     def get_sent_payment(self, sent_payment_id: int) -> Optional[SentPayment]:
         return self.squeak_store.get_sent_payment(sent_payment_id)
 
@@ -279,6 +246,18 @@ class SqueakController:
             last_received_payment,
         )
 
+    def get_received_payments_for_squeak(
+            self,
+            squeak_hash: bytes,
+            limit: int,
+            last_received_payment: Optional[ReceivedPayment],
+    ) -> List[ReceivedPayment]:
+        return self.squeak_store.get_received_payments_for_squeak(
+            squeak_hash,
+            limit,
+            last_received_payment,
+        )
+
     def delete_all_expired_offers(self):
         self.squeak_store.delete_all_expired_offers()
 
@@ -305,10 +284,6 @@ class SqueakController:
             limit: int,
             last_entry: Optional[SqueakEntry],
     ) -> List[SqueakEntry]:
-        # TODO: remove this temporary hack, after converting this to websockets.
-        # logger.info('Start downloading timeline...')
-        # self.network_controller.download_timeline()
-        # logger.info('Finished downloading timeline.')
         return self.squeak_store.get_timeline_squeak_entries(limit, last_entry)
 
     def get_liked_squeak_entries(
@@ -338,10 +313,6 @@ class SqueakController:
             limit: int,
             last_entry: Optional[SqueakEntry],
     ) -> List[SqueakEntry]:
-        # TODO: remove this temporary hack, after converting this to websockets.
-        logger.info('Start downloading pubkey squeaks...')
-        self.network_controller.download_pubkey_squeaks_async(public_key)
-        logger.info('Finished downloading pubkey squeaks.')
         return self.squeak_store.get_squeak_entries_for_public_key(
             public_key,
             limit,
@@ -381,6 +352,12 @@ class SqueakController:
     def get_sent_payment_summary(self) -> SentPaymentSummary:
         return self.squeak_store.get_sent_payment_summary()
 
+    def get_received_payment_summary_for_squeak(self, squeak_hash: bytes) -> ReceivedPaymentSummary:
+        return self.squeak_store.get_received_payment_summary_for_squeak(squeak_hash)
+
+    def get_sent_payment_summary_for_squeak(self, squeak_hash: bytes) -> SentPaymentSummary:
+        return self.squeak_store.get_sent_payment_summary_for_squeak(squeak_hash)
+
     def reprocess_received_payments(self) -> None:
         self.squeak_store.clear_received_payment_settle_indices()
         self.payment_processor.start_processing()
@@ -451,7 +428,7 @@ class SqueakController:
         )
 
     def get_default_peer_port(self) -> int:
-        return self.default_port
+        return 0  # TODO: remove default port method.
 
     def set_sell_price_msat(self, sell_price_msat: int) -> None:
         self.node_settings.set_sell_price_msat(sell_price_msat)
@@ -474,15 +451,20 @@ class SqueakController:
             profile_id,
             bearer_token,
         )
-        self.update_twitter_stream()
+        self.tweet_forwarder.restart()
         return twitter_account_id
 
     def get_twitter_accounts(self) -> List[TwitterAccountEntry]:
-        return self.squeak_store.get_twitter_accounts()
+        accounts = self.squeak_store.get_twitter_accounts()
+        return [
+            account._replace(
+                is_forwarding=self.tweet_forwarder.is_processing(
+                    account.handle,
+                ),
+            )
+            for account in accounts
+        ]
 
     def delete_twitter_account(self, twitter_account_id: int) -> None:
         self.squeak_store.delete_twitter_account(twitter_account_id)
-        self.update_twitter_stream()
-
-    def update_twitter_stream(self) -> None:
-        self.tweet_forwarder.start_processing()
+        self.tweet_forwarder.restart()
