@@ -83,6 +83,42 @@ class SqueakStore:
         self.new_follow_listener = EventListener()
         self.twitter_stream_change_listener = EventListener()
 
+    def make_squeak(
+            self,
+            profile_id: int,
+            content_str: str,
+            replyto_hash: Optional[bytes],
+            recipient_profile_id: Optional[int],
+    ) -> Optional[bytes]:
+        squeak_profile = self.get_squeak_profile(profile_id)
+        if squeak_profile is None:
+            raise Exception("Profile with id {} not found.".format(
+                profile_id,
+            ))
+        if recipient_profile_id:
+            recipient_profile = self.get_squeak_profile(
+                recipient_profile_id)
+            if recipient_profile is None:
+                raise Exception("Recipient profile with id {} not found.".format(
+                    recipient_profile_id,
+                ))
+        squeak, secret_key = self.squeak_core.make_squeak(
+            squeak_profile,
+            content_str,
+            replyto_hash,
+            recipient_profile=recipient_profile if recipient_profile_id else None,
+        )
+        inserted_squeak_hash = self.save_squeak(squeak)
+        if inserted_squeak_hash is None:
+            raise Exception("Failed to save squeak.")
+        self.save_secret_key(inserted_squeak_hash, secret_key)
+        if squeak.is_private_message:
+            self.unlock_squeak(
+                inserted_squeak_hash,
+                author_profile_id=profile_id,
+            )
+        return inserted_squeak_hash
+
     def save_squeak(self, squeak: CSqueak) -> Optional[bytes]:
         # Check if the squeak is valid context free.
         CheckSqueak(squeak)
@@ -173,6 +209,26 @@ class SqueakStore:
             squeak_hash.hex(),
         ))
 
+    def pay_offer(self, received_offer_id: int) -> int:
+        received_offer = self.get_received_offer(
+            received_offer_id,
+        )
+        if received_offer is None:
+            raise Exception("Received offer with id {} not found.".format(
+                received_offer_id,
+            ))
+        logger.info("Paying received offer: {}".format(received_offer))
+        sent_payment = self.squeak_core.pay_offer(received_offer)
+        sent_payment_id = self.save_sent_payment(sent_payment)
+        self.mark_received_offer_paid(
+            sent_payment.payment_hash,
+        )
+        self.save_secret_key(
+            received_offer.squeak_hash,
+            sent_payment.secret_key,
+        )
+        return sent_payment_id
+
     def get_squeak(self, squeak_hash: bytes) -> Optional[CSqueak]:
         return self.squeak_db.get_squeak(squeak_hash)
 
@@ -182,12 +238,6 @@ class SqueakStore:
     def delete_squeak(self, squeak_hash: bytes) -> None:
         self.squeak_db.delete_squeak(squeak_hash)
 
-    def get_sent_offer_by_squeak_hash_and_peer(self, squeak_hash: bytes, peer_address: PeerAddress) -> Optional[SentOffer]:
-        return self.squeak_db.get_sent_offer_by_squeak_hash_and_peer(
-            squeak_hash,
-            peer_address,
-        )
-
     def save_sent_offer(self, sent_offer: SentOffer) -> int:
         return self.squeak_db.insert_sent_offer(sent_offer)
 
@@ -197,13 +247,6 @@ class SqueakStore:
             peer_address: PeerAddress,
             price_msat: int,
     ) -> Optional[SentOffer]:
-        # Check if there is an existing offer for the hash/peer_address combination
-        sent_offer = self.get_sent_offer_by_squeak_hash_and_peer(
-            squeak_hash,
-            peer_address,
-        )
-        if sent_offer:
-            return sent_offer
         squeak = self.get_squeak(squeak_hash)
         secret_key = self.get_squeak_secret_key(squeak_hash)
         if squeak is None or secret_key is None:
@@ -363,6 +406,18 @@ class SqueakStore:
             last_sent_payment,
         )
 
+    def get_sent_payments_for_squeak(
+            self,
+            squeak_hash: bytes,
+            limit: int,
+            last_sent_payment: Optional[SentPayment],
+    ) -> List[SentPayment]:
+        return self.squeak_db.get_sent_payments_for_squeak(
+            squeak_hash,
+            limit,
+            last_sent_payment,
+        )
+
     def get_sent_payment(self, sent_payment_id: int) -> Optional[SentPayment]:
         return self.squeak_db.get_sent_payment(sent_payment_id)
 
@@ -382,6 +437,18 @@ class SqueakStore:
             last_received_payment,
         )
 
+    def get_received_payments_for_squeak(
+            self,
+            squeak_hash: bytes,
+            limit: int,
+            last_received_payment: Optional[ReceivedPayment],
+    ) -> List[ReceivedPayment]:
+        return self.squeak_db.get_received_payments_for_squeak(
+            squeak_hash,
+            limit,
+            last_received_payment,
+        )
+
     def delete_all_expired_offers(self):
         self.delete_all_expired_received_offers()
         self.delete_all_expired_sent_offers()
@@ -497,6 +564,12 @@ class SqueakStore:
     def get_sent_payment_summary(self) -> SentPaymentSummary:
         return self.squeak_db.get_sent_payment_summary()
 
+    def get_received_payment_summary_for_squeak(self, squeak_hash: bytes) -> ReceivedPaymentSummary:
+        return self.squeak_db.get_received_payment_summary_for_squeak(squeak_hash)
+
+    def get_sent_payment_summary_for_squeak(self, squeak_hash: bytes) -> SentPaymentSummary:
+        return self.squeak_db.get_sent_payment_summary_for_squeak(squeak_hash)
+
     def clear_received_payment_settle_indices(self) -> None:
         self.squeak_db.clear_received_payment_settle_indices()
 
